@@ -15,6 +15,7 @@ from junglead.json_encoder import JsonEncoder
 from junglead.datetime_util import DatetimeUtil, PlusFormat
 from junglead.regex_util import RegexUtil
 from junglead.email_util import EmailUtil, EmailItem, EmailAttachmentItem
+from junglead.snowflake_util import SnowflakeUtil
 
 
-__all__ = [LoggerUtil, LoggerLevel, JsonEncoder, DatetimeUtil, PlusFormat, RegexUtil, EmailUtil, EmailItem, EmailAttachmentItem]
+__all__ = [LoggerUtil, LoggerLevel, JsonEncoder, DatetimeUtil, PlusFormat, RegexUtil, EmailUtil, EmailItem, EmailAttachmentItem, SnowflakeUtil]
